@@ -7,12 +7,12 @@ from dotmap import DotMap
 from polygenic.data.data_accessor import DataAccessor
 from polygenic.model.utils import merge
 from polygenic.error.polygenic_exception import PolygenicException
-
-#tmp
-import json
+from enum import Enum
 
 logger = logging.getLogger('description_language.' + __name__)
 
+class VariantSource():
+    entries = ["genotyping", "ldproxy", "imputing", "af", "reference", "missing"]
 class SeqqlOperator:
 
     def __init__(self, entries):
@@ -123,37 +123,24 @@ class SeqqlOperator:
         return refined_result
 
     def compute_qc(self, genotypes):
-        qc = {"variant_count": 0,
-              "variant_count_genotyping": 0,
-                "variant_count_imputing": 0,
-                "variant_count_af": 0,
-                "variant_count_missing": 0,
-                "variant_fraction_genotyping": 0,
-                "variant_fraction_imputing": 0,
-                "variant_fraction_af": 0,
-                "variant_fraction_missing": 0,
-              }
+        qc = {}
+        for source in VariantSource.entries:
+            qc["variant_count"] = 0
+            qc["variant_count_" + source] = 0
+            qc["variant_fraction_" + source] = 0
         for variant_id in genotypes:
-            variant = genotypes[variant_id]
+            variant = genotypes[variant_id]["genotype"]
             qc["variant_count"] += 1
             if variant is not None and "source" in variant:
-                if variant["source"] == "genotyping":
-                    qc["variant_count_genotyping"] += 1
-                elif variant["source"] == "imputing":
-                    qc["variant_count_imputing"] += 1
-                elif variant["source"] == "af":
-                    qc["variant_count_af"] += 1
-                elif variant["source"] == "missing":
-                    qc["variant_count_missing"] += 1
+                if variant["source"] in VariantSource.entries:
+                    qc["variant_count_" + variant["source"]] += 1
                 else:
                     raise PolygenicException("Unknown genotype source for " + variant_id)
             else:
                 qc["variant_count_missing"] += 1
             if qc["variant_count"] > 0:
-                qc["variant_fraction_genotyping"] = qc["variant_count_genotyping"] / qc["variant_count"]
-                qc["variant_fraction_imputing"] = qc["variant_count_imputing"] / qc["variant_count"]
-                qc["variant_fraction_af"] = qc["variant_count_af"] / qc["variant_count"]
-                qc["variant_fraction_missing"] = qc["variant_count_missing"] / qc["variant_count"]
+                for source in VariantSource.entries:
+                    qc["variant_fraction_" + source] = round(qc["variant_count_" + source] / qc["variant_count"], 4)
         return qc
 class Description(SeqqlOperator):
     pass
@@ -177,8 +164,15 @@ class Category(SeqqlOperator):
 
     def compute(self, score: float):
         result = {"id": self.id, "match": False, "value": score}
-        if score >= self.get("from") and score <= self.get("to"):
-            result["match"] = True
+        if self.has("from") and not self.has("to"):
+            if score > self.get("from"):
+                result["match"] = True
+        if not self.has("from") and self.has("to"):
+            if score <= self.get("to"):
+                result["match"] = True
+        if self.has("from") and self.has("to"):
+            if score > self.get("from") and score <= self.get("to"):
+                result["match"] = True
         if self.has("scale_from") and self.has("scale_to"):
             result["value"] = self.get("scale_from") + (score - self.get("from")) / (self.get("to") - self.get("from")) * (self.get("scale_to") - self.get("scale_from"))
         return result
@@ -471,7 +465,7 @@ class ScoreModel(SeqqlOperator):
             "min": 0,
             "genotypes": {}
         }
-        for source in ["genotyping", "imputing", "af", "missing"]:
+        for source in VariantSource.entries:
             result[source + "_score"] = 0
             result[source + "_score_max"] = 0
             result[source + "_score_min"] = 0
